=======
History
=======

dlsia: Deep Learning for Scientific Image Analysis

0.2.0 (2023-01-26)
------------------
* First release - a rename of a previous project to better reflect name and scope.


0.3.0 (2023-01-26)
------------------
* Bug fixes and minor updates

0.3.1 (2023-01-26)
------------------
* New way to train networks
* Bug fixes
* Updated doc issues
